# Medial Tractography Analysis (MeTA) for White Matter Population Analyses Across Datasets

## References:

[1] Ba Gari, Iyad, et al. "Medial Tractography Analysis (MeTA) for White Matter Population Analyses Across Datasets." 2023 11th International IEEE/EMBS Conference on Neural Engineering (NER). IEEE, 2023.

## Contact:

bagari@usc.edu
